@@ -17,7 +17,7 @@ sub _carp {
 
 
 require Exporter;
-use vars qw($VERSION @ISA @EXPORT %EXPORT_TAGS $TODO);
+our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $TODO);
 $VERSION = '0.60';
 $VERSION = eval $VERSION;    # make the alpha version come out as a number
 
@@ -1001,7 +1001,7 @@ along these lines.
 
 =cut
 
-use vars qw(@Data_Stack %Refs_Seen);
+our (@Data_Stack, %Refs_Seen);
 my $DNE = bless [], 'Does::Not::Exist';
 sub is_deeply {
     unless( @_ == 2 or @_ == 3 ) {
